后台

# 控制台 查看

欢迎使用 Ace后台管理系统 (v1.2) ,轻量级好用的后台管理系统模版.
32
2个评论
8%
11
新粉丝
+32%
8
新订单
4%
7
调查
6,251
页面查看次数
7.2%
42%
交易使用
~ 剩余58GB
61%
任务
完成
获得
$32,000
下载次数
1,205

##### 访问来源

likes

#### 1,255

tweets

#### 941

pins

#### 1,050

#### 热门域名

名称 | 价格 | 状态
--- | --- | ---
internet.com | $29.99 $19.99 | 销售中
online.com | $16.45 | 可用
newnet.com | $15.00 | 待定
web.com | $24.99 $19.95 | 无货
domain.com | $12.00 | 售完

#### 销售统计

#### 最近

#### 可拖拽排序列表

- 问答
  42%
- BUG修复
- 添加新的特征
- 更新模版脚本
- 添加新皮肤
- 升级服务端
- 清理垃圾

Bob Doe
20 min
pending
Joe Doe
1 hour
pending
Jim Doe
2 hour
pending
Alex Doe
3 hour
blocked
Bob Doe
6 hour
approved
Susan
yesterday
approved
Phil Doe
2 days ago
online
Alexa Doe
3天以前
approved
查看所有会员
Bob Doe
6 min
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque commodo massa sed ipsum porttitor facilisis …
Jennifer
15 min
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque commodo massa sed ipsum porttitor facilisis …
Joe
22 min
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque commodo massa sed ipsum porttitor facilisis …
Rita
50 min
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque commodo massa sed ipsum porttitor facilisis …
See all comments

#### 会话

4秒钟前
Alexa
大家好啊
38秒以前
John
框架很好用嘛
2分钟以前
Bob admin
欢迎大家使用ACE后台管理系统.
3分钟以前
Jim
大家多提提BUG
4分钟以前
Alexa
继续支持ACE后台系统
选择皮肤
固定导航条
固定滑动条
固定面包屑
切换到左边
切换窄屏